agentle.mcp.sampling.completion\_result
=======================================

.. automodule:: agentle.mcp.sampling.completion_result

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      CompletionResult
      ImageMessageContent
      TextMessageContent
   